==> ktp-text-ui-0.6.2.1.tar.bz2: ktp-text-ui-0.6.2.1/filters/bugzilla/ktptextui_message_filter_bugzilla.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Bugzilla Information
Name[bs]=Bugzilla informacije
Name[ca]=Informació del Bugzilla
Name[cs]=Informace z bugzilly
Name[da]=Bugzilla-information
Name[el]=Πληροφορίες Bugzilla
Name[es]=Información de Bugzilla
Name[fi]=Bugzilla-tiedot
Name[fr]=Informations de Bugzilla
Name[gl]=Información de Bugzilla
Name[hu]=Bugzilla információk
Name[ia]=Information de Bugzilla
Name[it]=Informazioni di Bugzilla
Name[kk]=Bugzilla мәліметі
Name[lt]=Bugzilla informacija
Name[mr]=बगझिल्ला माहिती
Name[nl]=Informatie in Bugzilla
Name[pl]=Informacje Bugzilla
Name[pt]=Informação do Bugzilla
Name[pt_BR]=Informações do Bugzilla
Name[ro]=Informații Bugzilla
Name[ru]=Информация из Bugzilla
Name[sk]=Informácie o Bugzilla
Name[sl]=Podrobnosti o Bugzilli
Name[sr]=Бубаждајини подаци
Name[sr@ijekavian]=Бубаждајини подаци
Name[sr@ijekavianlatin]=Bubaždajini podaci
Name[sr@latin]=Bubaždajini podaci
Name[sv]=Bugzilla-information
Name[tr]=Bugzilla Bilgisi
Name[uk]=Дані у системі стеження за вадами
Name[x-test]=xxBugzilla Informationxx
Name[zh_CN]=Bugzilla 信息
Name[zh_TW]=Bugzilla 資訊
Comment=When receiving a link to a bug on bugzilla show additional information such as the title and status
Comment[bs]=Kada primite link na grešku na bugzilla, prikažite dodatnu informaciju kao što su naslov i status
Comment[ca]=En rebre un enllaç a un error del Bugzilla mostra informació addicional com el títol i l'estat
Comment[cs]=Pokud obdržíte odkaz na bugzillu zobrazí se v rozhovoru dodatečné informace jako stav a název
Comment[da]=Viser yderligere information såsom titel og status, når du modtager et link til en fejlrapport på bugzilla
Comment[el]=Κατά τη λήψη συνδέσμου σε ένα σφάλμα στο bugzilla να εμφανίζοντια επιπλέον πληροφορίες όπως ο τίτλος και η κατάσταση
Comment[es]=Cuando se recibe un enlace a un error en bugzilla se muestra información adicional como el título y el estado
Comment[fi]=Vastaanotettaessa vikailmoituslinkki bugzillaan näyttää lisätietoja kuten sen otsikon ja tilan
Comment[fr]=Lors de la réception d'un lien vers un bogue sur Bugzilla, affiche des information additionnelles telles que le titre et l'état
Comment[gl]=Cando se recibe unha ligazón a un erro en bugzilla mostra información adicional como o título e o estado
Comment[ia]=Quando on recip eun ligamine a un bug sur bugzilla on monstra information additional tal como le titulo e le stato
Comment[it]=Con collegamenti a bugzilla, mostra informazioni quali il titolo e lo stato dei bug relativi
Comment[kk]=Қаттеге сілтемені қабылдағанда bugzilla атауы мен күй-жайы секілді қосымша мәліметті көрсетеді
Comment[lt]=Kai gaunama nuoroda į klaidą sistemoje bugzilla, rodyti papildomą informaciją, tokią kaip pavadinimas ir būsena
Comment[nl]=Bij het ontvangen van een koppeling naar een bug in bugzilla toon dan extra informatie zoals de titel en de status
Comment[pl]=Przy otrzymywaniu odnośnika do błędu na bugzilli, pokaż dodatkowe informacje takie jak tytuł i stan
Comment[pt]=Ao receber uma hiperligação para um erro no Bugzilla, mostra informações adicionais como o título e o estado
Comment[pt_BR]=Mostra informações adicionais ao receber um link para um erro no Bugzilla, como o título e o status
Comment[ru]=При получении ссылки на ошибку в bugzilla будет показана дополнительная информация, в частности заголовок и состояние
Comment[sk]=Pri prijatí odkazu na chybu na Bugzille zobraziť dodatočné informácie ako titul a stav
Comment[sl]=Ko prejmete povezavo na hrošč na Bugzilli, prikaže dodatne podrobnosti kot recimo naslov in stanje
Comment[sr]=Додатни подаци при пријему везе до грешке са Бубаждаје, попут наслова и стања
Comment[sr@ijekavian]=Додатни подаци при пријему везе до грешке са Бубаждаје, попут наслова и стања
Comment[sr@ijekavianlatin]=Dodatni podaci pri prijemu veze do greške sa Bubaždaje, poput naslova i stanja
Comment[sr@latin]=Dodatni podaci pri prijemu veze do greške sa Bubaždaje, poput naslova i stanja
Comment[sv]=Visa ytterligare information när en länk till ett fel på Bugzilla tas emot, såsom rubrik och status
Comment[tr]=Bugzilla'daki bir hataya bağlantı alırken, başlık ve durum gibi ek bilgileri göster
Comment[uk]=У разі отримання посилання на запис вади у системі стеження за вадами показати додаткові дані, зокрема назву запису та стан вади
Comment[x-test]=xxWhen receiving a link to a bug on bugzilla show additional information such as the title and statusxx
Comment[zh_CN]=当收到错误或者 Bugziila 的链接时，将会显示额外信息，例如标题和状态
Comment[zh_TW]=接收到 bugzilla 上的連結時，顯示額外的資訊，如標題與狀態等
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_bugzilla
X-KDE-PluginInfo-Author=KDE Telepathy Developers
X-KDE-PluginInfo-Email=kde-telepathy@kde.org
X-KDE-PluginInfo-Name=bugzilla
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-0.6.80.tar.bz2: ktp-text-ui-0.6.80/filters/bugzilla/ktptextui_message_filter_bugzilla.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Bugzilla Information
Name[bs]=Bugzilla informacije
Name[ca]=Informació del Bugzilla
Name[cs]=Informace z bugzilly
Name[da]=Bugzilla-information
Name[de]=Bugzilla-Information
Name[el]=Πληροφορίες Bugzilla
Name[es]=Información de Bugzilla
Name[fi]=Bugzilla-tiedot
Name[fr]=Informations de Bugzilla
Name[gl]=Información de Bugzilla
Name[hu]=Bugzilla információk
Name[ia]=Information de Bugzilla
Name[it]=Informazioni di Bugzilla
Name[kk]=Bugzilla мәліметі
Name[lt]=Bugzilla informacija
Name[mr]=बगझिल्ला माहिती
Name[nl]=Informatie in Bugzilla
Name[pa]=ਬੱਗਜ਼ੀਲਾ ਜਾਣਕਾਰੀ
Name[pl]=Informacje Bugzilla
Name[pt]=Informação do Bugzilla
Name[pt_BR]=Informações do Bugzilla
Name[ro]=Informații Bugzilla
Name[ru]=Информация из Bugzilla
Name[sk]=Informácie o Bugzilla
Name[sl]=Podrobnosti o Bugzilli
Name[sr]=Бубаждајини подаци
Name[sr@ijekavian]=Бубаждајини подаци
Name[sr@ijekavianlatin]=Bubaždajini podaci
Name[sr@latin]=Bubaždajini podaci
Name[sv]=Bugzilla-information
Name[tr]=Bugzilla Bilgisi
Name[uk]=Дані у системі стеження за вадами
Name[x-test]=xxBugzilla Informationxx
Name[zh_CN]=Bugzilla 信息
Name[zh_TW]=Bugzilla 資訊
Comment=When receiving a link to a bug on bugzilla show additional information such as the title and status
Comment[bs]=Kada primite link na grešku na bugzilla, prikažite dodatnu informaciju kao što su naslov i status
Comment[ca]=En rebre un enllaç a un error del Bugzilla mostra informació addicional com el títol i l'estat
Comment[cs]=Pokud obdržíte odkaz na bugzillu zobrazí se v rozhovoru dodatečné informace jako stav a název
Comment[da]=Viser yderligere information såsom titel og status, når du modtager et link til en fejlrapport på bugzilla
Comment[de]=Wenn eine Verknüpfung zu einen Fehler in Bugzilla (KDE-Fehlerverfolgungssystem) eintrifft, werden zusätzliche Informationen wie Titel und Status angezeigt.
Comment[el]=Κατά τη λήψη συνδέσμου σε ένα σφάλμα στο bugzilla να εμφανίζοντια επιπλέον πληροφορίες όπως ο τίτλος και η κατάσταση
Comment[es]=Cuando se recibe un enlace a un error en bugzilla se muestra información adicional como el título y el estado
Comment[fi]=Vastaanotettaessa vikailmoituslinkki bugzillaan näyttää lisätietoja kuten sen otsikon ja tilan
Comment[fr]=Lors de la réception d'un lien vers un bogue sur Bugzilla, affiche des informations additionnelles telles que le titre et l'état
Comment[gl]=Cando se recibe unha ligazón a un erro en bugzilla mostra información adicional como o título e o estado
Comment[hu]=Egy bugzillán lévő hiba hivatkozásának fogadásakor további információk (cím és állapot) megjelenítése
Comment[ia]=Quando on recip eun ligamine a un bug sur bugzilla on monstra information additional tal como le titulo e le stato
Comment[it]=Con collegamenti a bugzilla, mostra informazioni quali il titolo e lo stato dei bug relativi
Comment[kk]=Қаттеге сілтемені қабылдағанда bugzilla атауы мен күй-жайы секілді қосымша мәліметті көрсетеді
Comment[lt]=Kai gaunama nuoroda į klaidą sistemoje bugzilla, rodyti papildomą informaciją, tokią kaip pavadinimas ir būsena
Comment[nl]=Bij het ontvangen van een koppeling naar een bug in bugzilla toon dan extra informatie zoals de titel en de status
Comment[pl]=Przy otrzymywaniu odnośnika do błędu na bugzilli, pokaż dodatkowe informacje takie jak tytuł i stan
Comment[pt]=Ao receber uma hiperligação para um erro no Bugzilla, mostra informações adicionais como o título e o estado
Comment[pt_BR]=Mostra informações adicionais ao receber um link para um erro no Bugzilla, como o título e o status
Comment[ru]=При получении ссылки на ошибку в bugzilla будет показана дополнительная информация, в частности заголовок и состояние
Comment[sk]=Pri prijatí odkazu na chybu na Bugzille zobraziť dodatočné informácie ako titul a stav
Comment[sl]=Ko prejmete povezavo na hrošč na Bugzilli, prikaže dodatne podrobnosti kot recimo naslov in stanje
Comment[sr]=Додатни подаци при пријему везе до грешке са Бубаждаје, попут наслова и стања
Comment[sr@ijekavian]=Додатни подаци при пријему везе до грешке са Бубаждаје, попут наслова и стања
Comment[sr@ijekavianlatin]=Dodatni podaci pri prijemu veze do greške sa Bubaždaje, poput naslova i stanja
Comment[sr@latin]=Dodatni podaci pri prijemu veze do greške sa Bubaždaje, poput naslova i stanja
Comment[sv]=Visa ytterligare information när en länk till ett fel på Bugzilla tas emot, såsom rubrik och status
Comment[tr]=Bugzilla'daki bir hataya bağlantı alırken, başlık ve durum gibi ek bilgileri göster
Comment[uk]=У разі отримання посилання на запис вади у системі стеження за вадами показати додаткові дані, зокрема назву запису та стан вади
Comment[x-test]=xxWhen receiving a link to a bug on bugzilla show additional information such as the title and statusxx
Comment[zh_CN]=当收到错误或者 Bugziila 的链接时，将会显示额外信息，例如标题和状态
Comment[zh_TW]=接收到 bugzilla 上的連結時，顯示額外的資訊，如標題與狀態等
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_bugzilla
X-KDE-PluginInfo-Author=KDE Telepathy Developers
X-KDE-PluginInfo-Email=kde-telepathy@kde.org
X-KDE-PluginInfo-Name=bugzilla
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
